@@ -2,10 +2,15 @@ package Term::Shell;
 
 use strict;
 use warnings;
+
+use 5.008;
+
 use Data::Dumper;
 use Term::ReadLine;
 
-our $VERSION = '0.03';
+use vars qw($VERSION);
+
+$VERSION = '0.05';
 
 #=============================================================================
 # Term::Shell API methods
@@ -49,7 +54,7 @@ sub new {
 	$attribs->{completion_function} = $completion_handler;
     }
     elsif ($o->{API}{readline} eq 'Term::ReadLine::Perl') {
-	$readline::rl_completion_function = 
+	$readline::rl_completion_function =
 	$readline::rl_completion_function = $completion_handler;
     }
     $o->find_handlers;
@@ -212,7 +217,7 @@ sub page_internal {
     else {
 	$instructions = "enter for more, or q to quit";
     }
-    
+
     if ($lines_left > 0) {
 	local $| = 1;
 	my $l = "---line $current_line/$total_lines ($instructions)---";
@@ -596,14 +601,14 @@ sub line_parsed {
 	}
 # We do not parse outside of strings
 #	elsif ($c eq '\\') {
-#	    $arg = (defined($arg) ? $arg : '') 
+#	    $arg = (defined($arg) ? $arg : '')
 #	      . $o->process_esc(substr($args,$i+1,1));
 #	    $i++;
 #	}
 	elsif ($c =~ /\s/) {
 	    push @args, $arg if defined $arg;
 	    $arg = undef
-	} 
+	}
 	else {
 	    $arg .= substr($args,$i,1);
 	}
@@ -716,7 +721,7 @@ sub possible_actions {
     my $action = shift;
     my $type = shift;
     my $casei = $o->{API}{case_ignore} ? '(?i)' : '';
-    my @keys =	grep { $_ =~ /$casei^\Q$action\E/ } 
+    my @keys =	grep { $_ =~ /$casei^\Q$action\E/ }
 		grep { exists $o->{handlers}{$_}{$type} }
 		keys %{$o->{handlers}};
     return @keys;
@@ -908,6 +913,10 @@ sub comp_ {
 
 package Term::Shell::OnScopeLeave;
 
+use vars qw($VERSION);
+
+$VERSION = '0.04';
+
 sub new {
     return bless [@_[1 .. $#_]], ref($_[0]) || $_[0];
 }
@@ -915,8 +924,10 @@ sub new {
 sub DESTROY {
     my $o = shift;
     for my $c (@$o) {
-	&$c;
+        $c->();
     }
+
+    return;
 }
 
 1;
